Index: src/heap/heap.h |
diff --git a/src/heap/heap.h b/src/heap/heap.h |
index 442d4dee1ace9108b8aa6b0a4a4e060e2aaacc15..3b6fd98da4f9cbe762c1754c2cdd0525e32065fe 100644 |
--- a/src/heap/heap.h |
+++ b/src/heap/heap.h |
@@ -1640,8 +1640,10 @@ |
static void ScavengeStoreBufferCallback(Heap* heap, MemoryChunk* page, |
StoreBufferEvent event); |
- // Selects the proper allocation space based on the pretenuring decision. |
- static AllocationSpace SelectSpace(PretenureFlag pretenure) { |
+ // Selects the proper allocation space depending on the given object |
+ // size and pretenuring decision. |
+ static AllocationSpace SelectSpace(int object_size, PretenureFlag pretenure) { |
+ if (object_size > Page::kMaxRegularHeapObjectSize) return LO_SPACE; |
return (pretenure == TENURED) ? OLD_SPACE : NEW_SPACE; |
} |